@@ -67,7 +67,7 @@ pkgOptions::~pkgOptions()
 {
   //  int i;
   //  for (i = 0; i < bnumber; i++) {
-  //    delete(Boxs[i]);
+  //    delete(Boxes[i]);
   //  }
 }
 
@@ -90,12 +90,12 @@ void pkgOptions::setupWidgets(QList<param *> &pars)
   // count number of buttons
   bnumber = pars.count();
 
-  Boxs = new QCheckBox *[bnumber];
+  Boxes = new QCheckBox *[bnumber];
   i = 0;
 //  for ( p=pars.first(); p != 0; p=pars.next(), i++ ) {
   foreach (param *p, pars) {
-    Boxs[i] = new QCheckBox(p->name);
-    Boxs[i]->setChecked(p->init);
+    Boxes[i] = new QCheckBox(p->name);
+    Boxes[i]->setChecked(p->init);
     i++;
   }
 
@@ -127,7 +127,7 @@ void pkgOptions::setupWidgets(QList<param *> &pars)
 
       layout->addStretch(1);
       for (i = 0; i < bnumber; i++) {
-	layout->addWidget(Boxs[i],1);
+	layout->addWidget(Boxes[i],1);
       }
       layout->addWidget(new KSeparator(Qt::Horizontal), 2);
 
@@ -266,7 +266,7 @@ void pkgOptions::pkginstallButtonClicked()
   int installFlags = 0;
 
   for (i = 0; i < bnumber; i++) {
-    installFlags |= (Boxs[i]->isChecked()) << i;
+    installFlags |= (Boxes[i]->isChecked()) << i;
   }
 
   test = false;
