@@ -1,21 +1,27 @@
 /***************************************************************************
-                          ksv_conf.cpp  -  description
-                             -------------------
     begin                : Sun Oct 3 1999
     copyright            : (C) 1997-99 by Peter Putzer
     email                : putzer@kde.org
  ***************************************************************************/
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; version 2.                              *
- *                                                                         *
- ***************************************************************************/
+/*
+   This program is free software; you can redistribute it and/or
+   modify it under the terms of the GNU General Public
+   License as published by the Free Software Foundation; either
+   version 2 of the License, or (at your option) any later version.
+
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+*/
+
 // KSysV Config Object
 
-#include <kapplication.h>
 #include <kglobal.h>
 #include <kglobalsettings.h>
 #include <kmainwindow.h>
@@ -23,6 +29,8 @@
 
 #include "ksv_core.h"
 #include "ksv_conf.h"
+//Added by qt3to4:
+#include <Q3ValueList>
 
 KSVConfig::KSVConfig ()
   : mConfig (KGlobal::config())
@@ -43,18 +51,16 @@ void KSVConfig::readSettings()
   mRunlevelPath = mConfig->readEntry("RunlevelPath", "/etc/rc.d");
 
   mConfig->setGroup("Other Settings");
-  mShowLog = mConfig->readBoolEntry("ShowLog", true);
-  mShowStatus = mConfig->readBoolEntry("StatusBar", true);
-  mShowTools = mConfig->readBoolEntry("ToolBar", true);
-  mConfigured = mConfig->readBoolEntry("Configured", false);
+  mShowLog = mConfig->readEntry("ShowLog", true);
+  mConfigured = mConfig->readEntry("Configured", false);
   mPanningFactor = mConfig->readNumEntry("PanningFactor", 80);
-  mShowDescription = mConfig->readBoolEntry("ShowDescription", true);
+  mShowDescription = mConfig->readEntry("ShowDescription", true);
 
   mConfig->setGroup("Colors");
-  mNewNormalColor = mConfig->readColorEntry ("New Text", &Qt::blue);
-  mNewSelectedColor = mConfig->readColorEntry ("New Selected Text", &Qt::blue);
-  mChangedNormalColor = mConfig->readColorEntry ("Changed Text", &Qt::red);
-  mChangedSelectedColor = mConfig->readColorEntry ("Changed Selected Text", &Qt::red); 
+  mNewNormalColor = mConfig->readColorEntry ("New Text", Qt::blue);
+  mNewSelectedColor = mConfig->readColorEntry ("New Selected Text", Qt::blue);
+  mChangedNormalColor = mConfig->readColorEntry ("Changed Text", Qt::red);
+  mChangedSelectedColor = mConfig->readColorEntry ("Changed Selected Text", Qt::red); 
 
   mConfig->setGroup("Fonts");
   QFont tmp = KGlobalSettings::generalFont();
@@ -74,15 +80,13 @@ void KSVConfig::readLegacySettings ()
 
   mConfig->setGroup("Other Settings");
 
-  mShowLog = mConfig->readBoolEntry("ShowLog", true);
-  mShowStatus = mConfig->readBoolEntry("StatusBar", true);
-  mShowTools = mConfig->readBoolEntry("ToolBar", true);
-  mConfigured = mConfig->readBoolEntry("Configured", false);
-  mPanningFactor = mConfig->readNumEntry("PanningFactor", 80);
-  mShowDescription = mConfig->readBoolEntry("ShowDescription", true);
+  mShowLog = mConfig->readEntry("ShowLog", true);
+  mConfigured = mConfig->readEntry("Configured", false);
+  mPanningFactor = mConfig->readEntry("PanningFactor", 80);
+  mShowDescription = mConfig->readEntry("ShowDescription", true);
   mConfig->setGroup("Colors");
-  mNewNormalColor = mConfig->readColorEntry("New", &Qt::blue);
-  mChangedNormalColor = mConfig->readColorEntry("Changed", &Qt::red);
+  mNewNormalColor = mConfig->readColorEntry("New", Qt::blue);
+  mChangedNormalColor = mConfig->readColorEntry("Changed", Qt::red);
 }
 
 void KSVConfig::writeSettings() {
@@ -92,8 +96,6 @@ void KSVConfig::writeSettings() {
 
   mConfig->setGroup("Other Settings");
   mConfig->writeEntry("ShowLog", mShowLog);
-  mConfig->writeEntry("StatusBar", mShowStatus);
-  mConfig->writeEntry("ToolBar", mShowTools);
   mConfig->writeEntry("Configured", mConfigured);
   mConfig->writeEntry("PanningFactor", mPanningFactor);
   mConfig->writeEntry("ShowDescription", mShowDescription);
@@ -116,8 +118,6 @@ void KSVConfig::writeSettings() {
       mConfig->setGroup("Geometry");
       mConfig->writeEntry("X-Position", mw->x());
       mConfig->writeEntry("Y-Position", mw->y());
-      mConfig->writeEntry("Width", mw->width());
-      mConfig->writeEntry("Height", mw->height());
     }
   
   writeRunlevels();
@@ -138,9 +138,9 @@ void KSVConfig::readRunlevels ()
 {
   mConfig->setGroup ("Runlevels");
   
-  QValueList<int> list = mConfig->readIntListEntry ("Show Runlevels");
+  Q3ValueList<int> list = mConfig->readIntListEntry ("Show Runlevels");
 
-  for (QValueList<int>::Iterator it = list.begin(); it != list.end(); ++it)
+  for (Q3ValueList<int>::Iterator it = list.begin(); it != list.end(); ++it)
 	mShowRunlevel[*it] = true;
 
   if (mShowRunlevel.isEmpty())
@@ -150,7 +150,7 @@ void KSVConfig::readRunlevels ()
 
 void KSVConfig::writeRunlevels ()
 {
-  QValueList<int> list;
+  Q3ValueList<int> list;
 
   for (QMap<int,bool>::Iterator it = mShowRunlevel.begin(); it != mShowRunlevel.end(); ++it)
 	if (it.data())
@@ -173,14 +173,6 @@ QPoint KSVConfig::position() const
 				mConfig->readNumEntry("Y-Position", 0));
 }
 
-QSize KSVConfig::size() const
-{
-  mConfig->setGroup("Geometry");
-  
-  return QSize(mConfig->readNumEntry("Width", 600),
-			   mConfig->readNumEntry("Height", 400));
-}
-
 void KSVConfig::setScriptPath (const QString& path)
 {
   mScriptPath = path;
@@ -237,5 +229,6 @@ void KSVConfig::setShowMessage (ksv::Messages msg, bool on)
 bool KSVConfig::showMessage (ksv::Messages msg) const
 {
   mConfig->setGroup("Notification Messages");
-  return mConfig->readBoolEntry (ksv::notifications[msg], true);
+  return mConfig->readEntry (ksv::notifications[msg], true);
 }
+
